# Nose plugin for print title info

This is a example use to print the title in python nose test framework.

## Require

nose >= 1.3.7

## Build

use command to build the package:

```sh
python -m build
```

## Attention

Nose test framework already not support in new python version, you can use pytest to build your test task.